==> xirc_1.17.orig.tar.gz: xirc-1.17.orig/ircreply.h <==
/*
** Irc Server Reply Definitions
**
** Copyright (C) 1995, 1996  Joseph Croft <jcroft@unicomp.net>
** 
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 1, or (at your option)
** any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

typedef enum
{
   RPL_TRACELINK=200, RPL_TRACECONNECTING, RPL_TRACEHANDSHAKE, RPL_UNKNOWN,
   RPL_TRACEOPERATOR, RPL_TRACEUSER, RPL_TRACESERVER,
   RPL_TRACENEWTYPE=208, RPL_TRACECLASS,
   RPL_STATSLINKINFO=211, RPL_STATSCOMMANDS, RPL_STATSCLINE, RPL_STATSNLINE,
   RPL_STATSILINE, RPL_STATSKLINE, RPL_STATSQLINE, RPL_STATSYLINE,
   RPL_ENDOFSTATS,
   RPL_STATSUMODEIS=221,
   RPL_SERVICEINFO=331, RPL_ENDOFSERVICES, RPL_SERVICE, RPL_SERVLIST,
   RPL_SERVLISTEND,
   RPL_STATSLLINE=241, RPL_STATSUPTIME, RPL_STATSOLINE, RPL_STATSHLINE,
   RPL_LUSERCLIENT=251, RPL_LUSEROP, RPL_LUSERUNKNOWN, RPL_LUSERNAME,
   RPL_ADMINME, RPL_ADMINLOC1, RPL_ADMINLOC2, RPL_ADMINEMAIL,
   RPL_TRACELOG=261,
   RPL_NONE=300, RPL_AWAY, RPL_USERHOST, RPL_ISON, RPL_UNAWAY, RPL_NOWAWAY, 
   RPL_WHOISUSER=311, RPL_WHOISSERVER, RPL_WHOISOPERATOR, RPL_WHOWASUSER,
   RPL_ENDOFWHO, RPL_WHOISCHANOP, RPL_WHOISIDLE, RPL_ENDOFWHOIS,
   RPL_WHOISCHANNELS, 
   RPL_LISTSTART=321, RPL_LIST, RPL_LISTEND, RPL_CHANNELMODEIS,
   RPL_NOTOPIC=331, RPL_TOPIC,
   RPL_INVITING=341, RPL_SUMMONING,
   RPL_VERSION=351, RPL_WHOREPLY, RPL_NAMEREPLY,
   RPL_KILLDONE=361, RPL+CLOSING, RPL_CLOSEEND, RPL_LINKS, RPL_ENDOFLINKS, 
   RPL_ENDOFNAMES, RPL_BANLIST, RPL_ENDOFBANLIST, RPL_ENDOFWHOWAS,
   RPL_INFO=371, RPL_MOTD, RPL_INFOSTART, RPL_ENDOFINFO, RPL_MOTDSTART,
   RPL_ENDOFMOTD,
   RPL_YOUREOPER=381, RPL_REHASHING, RPL_MYPORTIS,
   RPL_TIME=391, RPL_USERSTART, RPL_USERS, RPL_ENDOFUSERS, RPL_NOUSERS
} IrcReplies;

==> xirc_2.0.orig.tar.gz: xirc-2.0.orig/ircreply.h <==
/*
** Irc Server Reply Definitions
**
** Copyright (C) 1995, 1996  Joseph Croft <jcroft@unicomp.net>
** 
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 1, or (at your option)
** any later version.
** 
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
** 
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/
#ifndef IRCREPLY_H
#define IRCREPLY_H

typedef enum
{
   RPL_MAP=5,RPL_ENDOFMAP=7,
   RPL_TRACELINK=200, RPL_TRACECONNECTING, RPL_TRACEHANDSHAKE, RPL_UNKNOWN,
   RPL_TRACEOPERATOR, RPL_TRACEUSER, RPL_TRACESERVER,
   RPL_TRACENEWTYPE=208, RPL_TRACECLASS,
   RPL_STATSLINKINFO=211, RPL_STATSCOMMANDS, RPL_STATSCLINE, RPL_STATSNLINE,
   RPL_STATSILINE, RPL_STATSKLINE, RPL_STATSQLINE, RPL_STATSYLINE,
   RPL_ENDOFSTATS,
   RPL_STATSUMODEIS=221, RPL_TRACESERVICE=233, RPL_LUSERCHANNELS=254, RPL_LUSERME,
   RPL_SERVICEINFO=331, RPL_ENDOFSERVICES, RPL_SERVICE, RPL_SERVLIST,
   RPL_SERVLISTEND,
   RPL_STATSLLINE=241, RPL_STATSUPTIME, RPL_STATSOLINE, RPL_STATSHLINE,
   RPL_LUSERCLIENT=251, RPL_LUSEROP, RPL_LUSERUNKNOWN, RPL_LUSERNAME,
   RPL_ADMINME, RPL_ADMINLOC1, RPL_ADMINLOC2, RPL_ADMINEMAIL,
   RPL_TRACELOG=261,
   RPL_NONE=300, RPL_AWAY, RPL_USERHOST, RPL_ISON, RPL_UNAWAY, RPL_NOWAWAY, 
   RPL_WHOISUSER=311, RPL_WHOISSERVER, RPL_WHOISOPERATOR, RPL_WHOWASUSER,
   RPL_ENDOFWHO, RPL_WHOISCHANOP, RPL_WHOISIDLE, RPL_ENDOFWHOIS,
   RPL_WHOISCHANNELS, 
   RPL_LISTSTART=321, RPL_LIST, RPL_LISTEND, RPL_CHANNELMODEIS,
   RPL_NOTOPIC=331, RPL_TOPIC,
   RPL_INVITING=341, RPL_SUMMONING,
   RPL_VERSION=351, RPL_WHOREPLY, RPL_NAMEREPLY,
   RPL_KILLDONE=361, RPL_CLOSING, RPL_CLOSEEND, RPL_LINKS, RPL_ENDOFLINKS, 
   RPL_ENDOFNAMES, RPL_BANLIST, RPL_ENDOFBANLIST, RPL_ENDOFWHOWAS,
   RPL_INFO=371, RPL_MOTD, RPL_INFOSTART, RPL_ENDOFINFO, RPL_MOTDSTART,
   RPL_ENDOFMOTD,
   RPL_YOUREOPER=381, RPL_REHASHING, RPL_MYPORTIS,
   RPL_TIME=391, RPL_USERSTART, RPL_USERS, RPL_ENDOFUSERS, RPL_NOUSERS
} IrcReply;

#endif
